<?php 
/**
 * @package  DiveSitesManager
 * @since	1.2.0
 */
namespace cfishDSMInc\Pages;

use cfishDSMInc\Api\SettingsApi;
use cfishDSMInc\Base\BaseController;
use cfishDSMInc\Api\Callbacks\MapCallbacks;
use cfishDSMInc\Api\Callbacks\ManagerCallbacks;

class Map extends BaseController
{
	public $settings;

	public $callbacks;

	public $callbacks_mngr;

	public $pages = array();

	public function register()
	{

		//Add Image size control for Icons
		add_action( 'init', array( $this, 'add_new_image_size' ) );


		$this->settings = new SettingsApi();

		$this->callbacks = new MapCallbacks();

		$this->callbacks_mngr = new ManagerCallbacks();

		if ( $this->activated( 'maps_manager' ) ) {

			$this->setPages();

			$this->setSettings();
			$this->setSections();
			$this->setFields();

			$this->settings->addSubPages( $this->pages )->register();

		}
	}


	
	public function add_new_image_size() 
	{
		add_image_size('map_icon', 40, false);
	}

	public function setPages() 
	{
		$this->pages = array(
			array(
				'page_title' => __( 'Map Configuration', 'dive-sites-manager'), 
				'menu_title' => __('Map Configuration', 'dive-sites-manager'), 
				'capability' => 'manage_options', 
				'menu_slug' => 'dive_sites_map', 
				'callback' => array( $this->callbacks, 'mapDashboard' ), 
				'parent_slug' => 'dive_sites_manager',
				'position' => 110
			)
		);
	}

	public function setSettings()
	{
		$args = array(
			array(
				'option_group' => 'dive_sites_map_settings',
				'option_name' => 'cfish_dsm_map',
				'sanitize_callback' => array( $this->callbacks, 'validate_options' ),
			)
		);

		$this->settings->setSettings( $args );
	}

	public function setSections()
	{
		$args = array(
			array(
				'id' => 'dive_sites_map_admin_index',
				'title' => __('Map Configuration', 'dive-sites-manager'),
				'callback' => array( $this->callbacks, 'mapSectionManager' ),
				'page' => 'dive_sites_map'
			)
		);

		$this->settings->setSections( $args );
	}

	public function setFields()
	{
		$args = array();
		$args[] = array(
			'id' => 'height',
			'title' => __('Map Height (px)', 'dive-sites-manager'),
			'callback' => array( $this->callbacks_mngr, 'numberField' ),
			'page' => 'dive_sites_map',
			'section' => 'dive_sites_map_admin_index',
			'args' => array(
				'option_name' => 'cfish_dsm_map',
				'label_for' => 'height',
				'description' => __('Height of the map in pixels','dive-sites-manager'),
				'class' => '',
				'default' => '500',
				'max' => '800'
				)
		);
		$args[] = array(
			'id' => 'width',
			'title' => __('Map Width (%)', 'dive-sites-manager'),
			'callback' => array( $this->callbacks_mngr, 'numberField' ),
			'page' => 'dive_sites_map',
			'section' => 'dive_sites_map_admin_index',
			'args' => array(
				'option_name' => 'cfish_dsm_map',
				'label_for' => 'width',
				'description' => __('Width of the map in %','dive-sites-manager'),
				'class' => '',
				'default' => '80',
				'max' => '100'
				)
		);
		$args[] = array(
			'id' => 'icon',
			'title' => __('Dive Site Icon', 'dive-sites-manager'),
			'callback' => array( $this->callbacks_mngr, 'imageField' ),
			'page' => 'dive_sites_map',
			'section' => 'dive_sites_map_admin_index',
			'args' => array(
				'option_name' => 'cfish_dsm_map',
				'label_for' => 'icon',
				'description' => __('Image for the Dive Sites Markers on the map','dive-sites-manager'),
				'class' => '',
				)
		);
		$args[] = array(
			'id' => 'allow_zoom',
			'title' => __('Allow Zoom', 'dive-sites-manager'),
			'callback' => array( $this->callbacks_mngr, 'checkboxField' ),
			'page' => 'dive_sites_map',
			'section' => 'dive_sites_map_admin_index',
			'args' => array(
				'option_name' => 'cfish_dsm_map',
				'label_for' => 'allow_zoom',
				'description' => __('If selected the users will be able to zoom in the map','dive-sites-manager'),
				'class' => '',
				)
		);
		$standard = 'Standard <br><img src="' . $this->plugin_url . 'assets/standard.png">';
		$watercolor = 'Watercolor <br><img src="' . $this->plugin_url . 'assets/watercolor.png">';

		$args[] = array(
			'id' => 'map_tiles',
			'title' => __('Map Background', 'dive-sites-manager'),
			'callback' => array( $this->callbacks_mngr, 'radioField' ),
			'page' => 'dive_sites_map',
			'section' => 'dive_sites_map_admin_index',
			'args' => array(
				'option_name' => 'cfish_dsm_map',
				'label_for' => 'map_tiles',
				'description' => __('','dive-sites-manager'),
				'class' => 'cfish-radio-imgs',
				'values' => array ('standard' => $standard, 'watercolor' => $watercolor)
				)
		);
		$this->settings->setFields( $args );
	}

}